======
judson
======

Overview
--------

Howe-style dicts

Installation
------------

To install judson, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install judson

License
-------

This project is licensed under the MIT License.

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using judson!